@@ -28,7 +28,6 @@ status_flags = NamedTuple(
         ('image_build_failed', str),
         ('package_build_succeeded', str),
         ('image_build_succeeded', str),
-        ('package_build_running', str),
         ('buildroot_setup_failed', str),
         ('buildroot_setup_succeeded', str),
         ('package_request_accepted', str),
@@ -181,7 +180,6 @@ class Defaults:
             image_build_failed='image build failed',
             package_build_succeeded='package build succeeded',
             image_build_succeeded='image build succeeded',
-            package_build_running='package build running',
             buildroot_setup_failed='build root setup failed',
             buildroot_setup_succeeded='build root setup succeeded',
             package_request_accepted='package request accepted',
